@@ -380,10 +380,13 @@ void       UpdateChangingFlas (_SimpleList const & involvedVariables) {
 void DeleteVariable (long dv, bool deleteself, bool do_checks) {
     if (dv>=0L) {
 
+ 
         _String *name   = (_String*)variableNames.Retrieve (dv);
         _String my_name = *name&'.';
+        
         long    vidx    = variableNames.GetXtra (dv);
 
+
         UpdateChangingFlas (vidx);
 
         _SimpleList recCache;
@@ -547,7 +550,7 @@ void DeleteTreeVariable (long tree_variable_index, _SimpleList & parms, _String
         
         indices_to_delete.Each ([] (long var_idx, unsigned long) -> void {
             _Variable * delvar = LocateVar (var_idx);
-            //printf ("Deleting variable %s\n" , delvar->GetName()->get_str());
+            //printf ("DeleteTree::Deleting variable %s\n" , delvar->GetName()->get_str());
             if (delvar->ObjectClass() != TREE) {
                 variableNames.Delete (delvar->GetName(),true);
                 (*((_SimpleList*)&variablePtrs))[delvar->get_index()]=0;
@@ -671,12 +674,12 @@ bool CheckReceptacleAndStore (_String name, _String fID, bool checkValid, HBLObj
 
 //__________________________________________________________________________________
 void  InsertVar (_Variable* theV) {
-        
+    
+    
     long pos = variableNames.Insert (theV->theName);
-
-    if (pos < 0 && isDefiningATree == kTreeNodeBeingCreated)
+    
+    if (pos < 0 && isDefiningATree == kTreeNodeBeingCreated) {
         // automatically fix duplicate autogenerated tree node name
-    {
         long trySuffix  = 1;
         _String * tryName = new _String;
         do {
